@@ -31,9 +31,8 @@ extern "C" {
 
 /* Resources */
 #include "mupdf/fitz/store.h"
-#include "mupdf/fitz/colorspace.h"
+#include "mupdf/fitz/color.h"
 #include "mupdf/fitz/pixmap.h"
-#include "mupdf/fitz/glyph.h"
 #include "mupdf/fitz/bitmap.h"
 #include "mupdf/fitz/image.h"
 #include "mupdf/fitz/shade.h"
@@ -41,7 +40,7 @@ extern "C" {
 #include "mupdf/fitz/path.h"
 #include "mupdf/fitz/text.h"
 #include "mupdf/fitz/separation.h"
-#include "mupdf/fitz/color-management.h"
+#include "mupdf/fitz/glyph.h"
 
 #include "mupdf/fitz/device.h"
 #include "mupdf/fitz/display-list.h"
@@ -54,22 +53,14 @@ extern "C" {
 #include "mupdf/fitz/link.h"
 #include "mupdf/fitz/outline.h"
 #include "mupdf/fitz/document.h"
-#include "mupdf/fitz/annotation.h"
 
 #include "mupdf/fitz/util.h"
 
 /* Output formats */
 #include "mupdf/fitz/writer.h"
 #include "mupdf/fitz/band-writer.h"
-#include "mupdf/fitz/output-pnm.h"
-#include "mupdf/fitz/output-png.h"
-#include "mupdf/fitz/output-pwg.h"
-#include "mupdf/fitz/output-pcl.h"
-#include "mupdf/fitz/output-pclm.h"
-#include "mupdf/fitz/output-ps.h"
-#include "mupdf/fitz/output-psd.h"
+#include "mupdf/fitz/write-pixmap.h"
 #include "mupdf/fitz/output-svg.h"
-#include "mupdf/fitz/output-tga.h"
 
 #ifdef __cplusplus
 }
